@@ -857,9 +857,9 @@ def annotate_with_ef(doc):
                                                     }
                                                 ]
                                         },
-                                        {
-                                            "propertyId": "P686"
-                                        },
+                                        # {
+                                        #     "propertyId": "P686"
+                                        # },
                                         {
                                             "$and":
                                                 [
@@ -1043,7 +1043,7 @@ def annotate_with_ef(doc):
     return doc
 
 
-# @pytest.mark.skip(reason="Not a test")
+@pytest.mark.skip(reason="Not a test")
 def test_scai_ef():
     testdir = Path('/media/olivier/DATA/corpora/SCAI/MedlineCorpus-Schizophrenia-BipolarDisorder-20210907')
     token = get_token()
@@ -1295,17 +1295,3 @@ def test_scai_eval_ef():
                         print(json.dumps(row), file=fout)
             else:
                 print("SKIP")
-
-
-@pytest.mark.skip(reason="Not a test")
-def test_diff():
-    testdir = Path('/media/olivier/DATA/corpora/SCAI/MedlineCorpus-Schizophrenia-BipolarDisorder-20210907')
-    opennres = set()
-    pubmeds = set()
-    for opennre_gz in testdir.glob('*_opennre.json.gz'):
-        opennres.add(opennre_gz.stem[0:26])
-    donedir = Path('/media/olivier/DATA/corpora/SCAI/MedlineCorpus-Schizophrenia-BipolarDisorder-20210907/done')
-    for pubmed_gz in donedir.glob('*.xml.gz'):
-        pubmeds.add(pubmed_gz.stem[0:26])
-    print(opennres.difference(pubmeds))
-    print(pubmeds.difference(opennres))
